==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/slopemapdialog.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** SlopeMapWidget.h
*/
#ifndef __SlopeMapWidget_H__
#define __SlopeMapWidget_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <qcombobox.h>
#include <qdialog.h>
#include <qlineedit.h>

#include <color.h>
#include "../../3d/textures/slopemap.h"
#include <qcolor.h>
#include "slopeentrywidget.h"
// #include "patternmodifierdialog.h"

class PatternModifierWidget;
class TransformationsWidget;
class TurbulenceWidget;
class TabWidget;

class SlopeMapWidget : public QWidget
{
Q_OBJECT
protected:
	slopeMap *sm;

	TabWidget		*tab;

	TransformationsWidget 	*tw;
	TurbulenceWidget 	*tbw;
	PatternModifierWidget *pmd;

	QLineEdit		*line;
	QPushButton		*transformations,*turbulence,*add;
	QCheckBox		*active;
	QLabel			*n,*label4;

	list<SlopeEntryWidget *>	slopewidget;
	list<QWidget *>			widgetlist;


public:

	SlopeMapWidget(QWidget *p, slopeMap *);
	~SlopeMapWidget();
	void getSlopeMap();

protected:
	void	paintEvent(QPaintEvent*);
public slots:

	void transformationsPressed();
	void turbulencePressed();
	void addClicked();

};

//--------------------------------------------------------

class SlopeMapDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	SlopeMapWidget		*pw;

public:

	SlopeMapDialog(QWidget *p, slopeMap *);
	~SlopeMapDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void okayPressed();
	void cancelPressed();
};
#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/slopemapdialog.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** slopemapdialog.h
*/
#ifndef __SlopeMapWidget_H__
#define __SlopeMapWidget_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcombobox.h>
#include <qdialog.h>
#include <qlineedit.h>

#include "../../3d/textures/slopemap.h"

#include <misc.h>
#include "texturebasewidget.h"


#include "texturewidgetbase.h"

class PatternModifierWidget;

class SlopeMapWidget : public TextureWidgetBase
{
Q_OBJECT
protected:
	slopeMap *sm;

	TextureBaseWidget	*tbasew;
	PatternModifierWidget 	*pmd;

	QLabel			*label4;
	QSize			qs;

public:

	SlopeMapWidget(QWidget *p, slopeMap *);
	~SlopeMapWidget();
	void getValue();
	virtual QSize	sizeHint() const;

protected:
	void	paintEvent(QPaintEvent*);
};

//--------------------------------------------------------

class SlopeMapDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	SlopeMapWidget		*pw;

public:

	SlopeMapDialog(QWidget *p, slopeMap *);
	~SlopeMapDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void okayPressed();
	void cancelPressed();
};
#endif
